@@ -54,6 +54,10 @@ class Schema(object):
   def name(self):
     return self._name
 
+  @property
+  def host(self):
+    return self._host
+
   def store(self, stat, val, timestamp=None):
     '''
     Store a value in this schema.
@@ -62,8 +66,10 @@ class Schema(object):
       if self._transform:
         stat,val = self._transform(stat,val)
         if stat is None:
-          return
+          return False
       self.timeseries.insert(stat, val, timestamp)
+      return True
+    return False
 
   def _match_single(self, stat):
     '''
